#!/usr/bin/env python
# -*- coding: UTF-8 -*-
"""
Script d'utilisation du capteur de pression BMP085/180 sur I2C

sudo python bmp085.py offset_temp parameter

 parameter   description
 altitude    request altitude from sea level (meters)
 offset_temp offset for temperature (°C)
 temperature request temperature (°C)
 pressure    request pressure at sea level (hPa)
 
Examples: 
"sudo python bmp085.py 60 temperature" return temperature -7.2°C offset
"sudo python bmp085.py 60 pression" return pressure in hPa
"""
#
#Thanks to ADAFRUIT BMP085 library : https://github.com/adafruit/Adafruit_Python_BMP
#To install, download the library by clicking the download zip link to the right and unzip the archive somewhere on your Raspberry Pi.
#Then execute the following command in the directory of the library:
#
#sudo python setup.py install
 
#add user www-data to i2c group : sudo adduser www-data i2c

# Can enable debug output by uncommenting:
#import logging
#logging.basicConfig(level=logging.DEBUG)
import Adafruit_BMP.BMP085 as BMP085
import sys

# Default constructor will pick a default I2C bus.
#
# For the Raspberry Pi this means you should hook up to the only exposed I2C bus
# from the main GPIO header and the library will figure out the bus number based
# on the Pi's revision.
#
# For the Beaglebone Black the library will assume bus 1 by default, which is
# exposed with SCL = P9_19 and SDA = P9_20.
sensor = BMP085.BMP085()

# Optionally you can override the bus number:
#sensor = BMP085.BMP085(busnum=2)

# You can also optionally change the BMP085 mode to one of BMP085_ULTRALOWPOWER,
# BMP085_STANDARD, BMP085_HIGHRES, or BMP085_ULTRAHIGHRES. See the BMP085
# datasheet for more details on the meanings of each mode (accuracy and power
# consumption are primarily the differences). The default mode is STANDARD.
#sensor = BMP085.BMP085(mode=BMP085.BMP085_ULTRAHIGHRES)

#Calculates the pressure at given altitude in meters. Returns a value in hPa.
offset_temp = float(sys.argv[1])

if sys.argv[2] == "temperature":
 print str(sensor.read_temperature() + offset_temp)
elif sys.argv[2] == "pression":
 print str(sensor.read_sealevel_pressure() / 100)
elif sys.argv[2] == "altitude":
 print str(int(sensor.read_altitude()))
else:
 print "Erreur"
